@@ -18,7 +18,8 @@ sub run {
     = Mojo::IOLoop::Client->can_socks ? $IO::Socket::Socks::VERSION : 'n/a';
   my $tls = Mojo::IOLoop::TLS->can_tls    ? $IO::Socket::SSL::VERSION  : 'n/a';
   my $nnr = Mojo::IOLoop::Client->can_nnr ? $Net::DNS::Native::VERSION : 'n/a';
-  my $roles = Mojo::Base->ROLES ? $Role::Tiny::VERSION : 'n/a';
+  my $roles = Mojo::Base->ROLES ? $Role::Tiny::VERSION                 : 'n/a';
+  my $async = Mojo::Base->ASYNC ? $Future::AsyncAwait::Frozen::VERSION : 'n/a';
 
   print <<EOF;
 CORE
@@ -26,12 +27,13 @@ CORE
   Mojolicious ($Mojolicious::VERSION, $Mojolicious::CODENAME)
 
 OPTIONAL
-  Cpanel::JSON::XS 4.09+  ($json)
-  EV 4.0+                 ($ev)
-  IO::Socket::Socks 0.64+ ($socks)
-  IO::Socket::SSL 2.009+  ($tls)
-  Net::DNS::Native 0.15+  ($nnr)
-  Role::Tiny 2.000001+    ($roles)
+  Cpanel::JSON::XS 4.09+           ($json)
+  EV 4.0+                          ($ev)
+  IO::Socket::Socks 0.64+          ($socks)
+  IO::Socket::SSL 2.009+           ($tls)
+  Net::DNS::Native 0.15+           ($nnr)
+  Role::Tiny 2.000001+             ($roles)
+  Future::AsyncAwait::Frozen 0.36+ ($async)
 
 EOF
 
